
<!-- ----------------------------------------------------------------- -->
/*
 * validation.js
 */
  
/**
 *
 * Function tests a integer to see if it
 * is a standard ascii file name character.
 *
 * Used in URLEncodeString(aStr).
 *
 */ 
function isAsciiFileNameChar(aInt)
{
	// Test basic ascii
	if(isAsciiNameChar(aInt))
		return(true);

	// Test [\]
	if(aInt == 92)
		return(true);

	// Test [/]
	if(aInt == 47)
		return(true);

	// Test [.]
	if(aInt == 46)
		return(true);

	// Test [-]
	if(aInt == 45)
		return(true);

	return(false);
}

/**
 *
 * Function tests a integer to see if it
 * is a standard ascii character.
 *
 */ 
function isAsciiNameChar(aInt)
{
	// Test [a - z]
	if((aInt > 96) && (aInt < 123))
		return(true);

	// Test [A - Z]
	if((aInt > 64) && (aInt < 91))
		return(true);

	// Test [0 - 9]
	if((aInt > 47) && (aInt < 58))
		return(true);

	// Test [_]
	if(aInt == 95)
		return(true);

	return(false);
}

/**
 *
 * Function tests a integer to see if it
 * is a allowable latin character.
 *
 */ 
function isLatinNameChar(aInt)
{
	// Test Latin upper case [192 - 223]
	if((aInt > 191) && (aInt < 224))
		return(true);

	// Test Latin lower case [224 - 255]
	if((aInt > 223) && (aInt < 256))
		return(true);

	return(false);
}

/**
 *
 * Function tests a integer to see if it
 * is a allowable unicode character.
 *
 */ 
function isUnicodeNameChar(aInt)
{
	// Test unicode [256 - 65535]
	if((aInt > 255) && (aInt < 65536))
		return(true);

	return(false);
}

/**
 *
 * Function is the same as javascript escape().
 *
 * Except it uses '' instead of '%' or '%u'.
 *
 * This is used to map to values produced by
 * our java CSURLEncoder.encodeFileName16(String s)
 * method.
 *
 */ 
function URLEncodeString(aStr)
{
	var i,j,z;
	var x,y;
	var retVal = "";

	for(i=0, j=aStr.length; i<j; i++)
	{
		x = aStr.charCodeAt(i);
		
		if(isAsciiFileNameChar(x))
		{
			retVal = retVal + aStr.charAt(i);
		}
		else
		{
			y = Number(x).toString(16);
			z = y.length;

			if(x > 255)
			{
				if(z == 1)
					retVal = retVal + "000";
				else if(z == 2)
					retVal = retVal + "00";
				else if(z == 3)
					retVal = retVal + "0";
			}
			else
			{
				if(z == 1)
					retVal = retVal + "0";
			}

			retVal = retVal + y;
		}
	}

	return(retVal);
}

/**
 *
 * Validates a unicode name value.
 *
 * Only [a-z][A-Z][0-9][_] and
 * Latin characters are allowable.
 * characters > 255 are allowable.
 *
 */ 
function ValidUnicodeName(aStr)
{
	var i,j,x;

	for(i=0, j=aStr.length; i<j; i++)
	{
		x = aStr.charCodeAt(i);
		//alert("Character: '" + x + "','" + aStr.charAt(i) + "'");
		
		if(!isAsciiNameChar(x))
			if(!isLatinNameChar(x))
				if(!isUnicodeNameChar(x))
					return(false);
	}

	return(true);
}
 
 //allow unicode and also pipe symbol
function validUnicodeNameOrPipe(aStr)
{
	var i,j,x;

	for (i = 0, j = aStr.length; i < j; i++)
	{
		x = aStr.charCodeAt(i);
			
		if (!isAsciiNameChar(x))
			if (!isLatinNameChar(x))
				if (!isUnicodeNameChar(x))
					if (!isPipe(x))
						return false;
	}

	return true;
}

function isPipe(aStr)
{
	if (aStr == 124)
	{
		return true;
	}
	
	return false;
}

/**
 *
 * Checks to see if a string has white space characters..
 *
 */
function hasNonWhiteSpaceChar(aStr)
{
	if(aStr == null)
		return(false);

	if(aStr.length == 0)
		return(false);

	return(aStr.search(/\S/) >= 0);
}

/**
 * Function used for validating a string for ASCII characters.
 * param aStr,     	String to be validated
 * return boolean, 	true if the string contains only 7-bit ASCII characters
 *		   		    false if the string contains non-ASCII characters	
 */ 
function validASCII(aStr)
{
	return(aStr.match(/[^\x00-\x7F]/) == null);
}

/**
 * Function used for replacing non-ASCII characters in the string with '_' character(s).
 * param aStr,   	String to be processed
 * return String,  	String with the non-ASCII characters replaced
 */ 
function replaceNonASCII(aStr)
{
	return aStr.replace(/[^\x00-\x7F]/g, "_");
}

/**
 *
 * Validates a file name.
 *
 */
function ValidFileName(aStr)
{
	return(aStr.match(/^[a-zA-Z0-9_\-\\\/\.]+$/) != null);
}

/**
 *
 * Trim the spaces from the left and right sides.
 *
 */
function trim(aStr)
{
	return(ltrim(rtrim(aStr)));
}

/**
 *
 * Trim the spaces from the left side.
 *
 */
function ltrim(aStr)
{
	var lpatt = new RegExp("^ *(.*)$");
	var parse = aStr.match(lpatt);
	return(parse[1]);
}

/**
 *
 * Trim the spaces from the right side.
 *
 */
function rtrim(aStr)
{
	var rpatt = new RegExp("^(.*[^ ]) *$");
	var parse = aStr.match(rpatt);
	return(parse[1]);
}

/**
 *
 * Replaces non-valid characters in a variable name.
 *
 */
function NameReplace(aStr)
{
	var aStr2 = aStr.replace(/[^a-zA-Z0-9_]/g, "_");
	return(aStr2.replace(/^[0-9]/, "_"));
}

/**
 *
 * Replaces non-valid characters in a variable name.
 * Allows non-ascii characters.
 *
 */
function NameReplaceAllowNonAscii(aStr)
{
	var i,j,x;
	var ReturnString = "";

	for(i=0, j=aStr.length; i<j; i++)
	{
		x = aStr.charCodeAt(i);
		//alert("Character: '" + x + "','" + aStr.charAt(i) + "'");
		
		if(isAsciiNameChar(x))
			ReturnString += aStr.charAt(i);
		else if(isLatinNameChar(x))
			ReturnString += aStr.charAt(i);
		else if(isUnicodeNameChar(x))
			ReturnString += aStr.charAt(i);
		else
			ReturnString += "_";
	}

	return(ReturnString);
}

/**
 *
 * Validates a ascii-only variable name.
 *
 */
function ValidAsciiName(aStr)
{
	return(aStr.match(/^[a-zA-Z_][a-zA-Z0-9_]*$/) != null);
}

/**
 *
 * Validates a variable name.
 *
 */
function ValidName(aStr)
{
	if(aStr == "{BLANK}")
		return(true);

	if(aStr == "{LINE}")
		return(true);
		
	if(aStr == "{BEGIN_SECTION}")
		return(true);
		
	if(aStr == "{END_SECTION}")
		return(true);
		
	if(aStr == "HTML_TEXT}")
		return(true);

	return(ValidAsciiName(aStr));
}

/**
 *
 * Validates a user name.
 *
 */
function ValidUserName(aStr)
{
	return (aStr.match(/^[a-zA-Z0-9_][a-zA-Z0-9_.-]*$/) != null);
}

/**
 *
 * Validates a variable name.
 * Allows non-ascii characters.
 *
 */
function ValidAllowNonAsciiName(aStr)
{
	if (aStr == "{BLANK}")
		return true;

	if (aStr == "{LINE}")
		return true;
	
	if (aStr == "{BEGIN_SECTION}")
		return true;
		
	if (aStr == "{END_SECTION}")
		return true;
	
	if (aStr == "{HTML_TEXT}")
		return true;
		
	if (aStr == "{BASELINES}")
		return true;

	return ValidUnicodeName(aStr);
}

/**
 *
 * Xml encodes a string.
 * Only the characters '<','>','&', are considered.
 *
 */
function xmlEncode(aStr)
{
	if (!aStr)
	{
		return(aStr);
	}
	
	if(aStr.length == 0)
		return(aStr);

	var aStr1 =  aStr.replace(/&/g, "&amp;");
	var aStr2 = aStr1.replace(/</g, "&lt;");
	var aStr3 = aStr2.replace(/>/g, "&gt;");

	return(aStr3);
}


/**
 *
 * HTML encodes a string.
 * Only the characters <>&"' are considered.
 *
 */
function htmlEncode(aStr)
{
	if(aStr.length == 0)
		return(aStr);

	var temp;

	temp = aStr.replace(/&/g, "&amp;");
	temp = temp.replace(/</g, "&lt;");
	temp = temp.replace(/>/g, "&gt;");
	temp = temp.replace(/'/g, "&#039;");
	temp = temp.replace(/"/g, "&quot;");

	return(temp);
}

/**
 *
 * Replaces newline characters with a space character in a string.
 *
 */
function noNewLines(aStr)
{
	return(aStr.replace(/\r?\n/g, " "));
}

/**
 *
 * Validates that the value is a number.
 *
 */
function ValidNum(aStr)
{
	if(isNaN(parseInt(aStr,10)))
		return false;
	else
		return true;
}

/**
 *
 * Encodes a database name.
 * Replaces all '\' with '|' character.
 *
 */
function EncodeDatabase(aStr)
{
	return(aStr.replace(/\\/g, "|"));
}

/**
 *
 * Unencodes a database name.
 * Replaces all '|' with '\' character.
 *
 */
function unEncodeDatabase(aStr)
{
	return(aStr.replace(/\|/g, "\\"));
}


/**
 * Validates whether the input is valid.
 */
function isValidInput(field)
{
	var userInput = field.value;
	
	// Test for a valid Number (int or float).				
	if (/^-?\d*(\.\d+)?$/.test(userInput))
	{
		return true;
	}
	else
	{
		alert('<!-- WSLET CODE=PTString --><!-- PARAM NAME=RESOURCE_STRING VALUE=err00119 --><!-- /WSLET -->', 1);
		return false;			
	}
}
<!-- END validation.js -->
<!-- ----------------------------------------------------------------- -->
